#! /usr/bin/env python
# -*- coding: utf-8 -*-
# vim:fenc=utf-8

"""
Import the Plugin class.
"""

from meerschaum.core.Plugin._Plugin import Plugin
